# This file is encoded in ShiftJIS.
die "This file is not encoded in ShiftJIS.\n" if q{} ne "\x82\xa0";

use Sjis;

# G[ɂ͂ȂȂǕiRj
print "ۏ\net";

__END__

Sjis.pm ̏ʂȉɂȂ邱Ƃ҂Ă

print "ۏ\\net";

Shift-JISeLXg𐳂
http://homepage1.nifty.com/nomenclator/perl/shiftjis.htm
